@@ -9,7 +9,7 @@ except ImportError:
     # Python 3+
     from urllib.parse import urlparse
 from simple_salesforce.login import SalesforceLogin
-from simple_salesforce.util import date_to_iso8601
+from simple_salesforce.util import date_to_iso8601, SalesforceError
 
 try:
     from collections import OrderedDict
@@ -168,7 +168,7 @@ class Salesforce(object):
         result = self.request.post(url, headers=self.headers, data=json.dumps(params))
 
         # salesforce return 204 No Content when the request is successful
-        if result.status_code != 200 or result.status_code != 204:
+        if result.status_code != 200 and result.status_code != 204:
             raise SalesforceGeneralError(result.content)
         json_result = result.json(object_pairs_hook=OrderedDict)
         if len(json_result) == 0:
@@ -202,7 +202,7 @@ class Salesforce(object):
             return None
         else:
             return json_result
-        
+
     # Search Functions
     def search(self, search):
         """Returns the result of a Salesforce search as a dict decoded from
@@ -347,12 +347,7 @@ class Salesforce(object):
 
         Returns a `requests.result` object.
         """
-        headers = {
-            'Content-Type': 'application/json',
-            'Authorization': 'Bearer ' + self.session_id,
-            'X-PrettyPrint': '1'
-        }
-        result = self.request.request(method, url, headers=headers, **kwargs)
+        result = self.request.request(method, url, headers=self.headers, **kwargs)
 
         if result.status_code >= 300:
             _exception_handler(result)
@@ -585,7 +580,7 @@ def _exception_handler(result, name=""):
         raise SalesforceGeneralError(message)
 
 
-class SalesforceMoreThanOneRecord(Exception):
+class SalesforceMoreThanOneRecord(SalesforceError):
     """
     Error Code: 300
     The value returned when an external ID exists in more than one record. The
@@ -594,7 +589,7 @@ class SalesforceMoreThanOneRecord(Exception):
     pass
 
 
-class SalesforceMalformedRequest(Exception):
+class SalesforceMalformedRequest(SalesforceError):
     """
     Error Code: 400
     The request couldn't be understood, usually becaue the JSON or XML body contains an error.
@@ -602,7 +597,7 @@ class SalesforceMalformedRequest(Exception):
     pass
 
 
-class SalesforceExpiredSession(Exception):
+class SalesforceExpiredSession(SalesforceError):
     """
     Error Code: 401
     The session ID or OAuth token used has expired or is invalid. The response
@@ -611,7 +606,7 @@ class SalesforceExpiredSession(Exception):
     pass
 
 
-class SalesforceRefusedRequest(Exception):
+class SalesforceRefusedRequest(SalesforceError):
     """
     Error Code: 403
     The request has been refused. Verify that the logged-in user has
@@ -620,7 +615,7 @@ class SalesforceRefusedRequest(Exception):
     pass
 
 
-class SalesforceResourceNotFound(Exception):
+class SalesforceResourceNotFound(SalesforceError):
     """
     Error Code: 404
     The requested resource couldn't be found. Check the URI for errors, and
@@ -629,7 +624,7 @@ class SalesforceResourceNotFound(Exception):
     pass
 
 
-class SalesforceGeneralError(Exception):
+class SalesforceGeneralError(SalesforceError):
     """
     A non-specific Salesforce error.
     """
