@@ -30,3 +30,8 @@ def date_to_iso8601(date):
         tzsign=timezone_sign,
         timezone=timezone_str
         ).replace(':', '%3A').replace('+', '%2B')
+
+
+class SalesforceError(Exception):
+    """Base Salesforce API exception"""
+    pass
